@@ -771,7 +771,7 @@ class APIHandler(JupyterHandler):
         # record activity of authenticated requests
         if (
             self._track_activity
-            and getattr(self, "_user_cache", None)
+            and getattr(self, "_jupyter_current_user", None)
             and self.get_argument("no_track_activity", None) is None
         ):
             self.settings["api_last_activity"] = utcnow()
@@ -855,6 +855,7 @@ class AuthenticatedFileHandler(JupyterHandler, web.StaticFileHandler):
     @authorized
     def get(self, path, **kwargs):
         """Get a file by path."""
+        self.check_xsrf_cookie()
         if os.path.splitext(path)[1] == ".ipynb" or self.get_argument("download", None):
             name = path.rsplit("/", 1)[-1]
             self.set_attachment_header(name)
@@ -1016,6 +1017,8 @@ class FileFindHandler(JupyterHandler, web.StaticFileHandler):
 class APIVersionHandler(APIHandler):
     """An API handler for the server version."""
 
+    _track_activity = False
+
     def get(self):
         """Get the server version info."""
         # not authenticated, so give as few info as possible
