@@ -6,6 +6,7 @@ import logging
 import mimetypes
 import os
 import random
+import warnings
 from typing import Optional, cast
 
 from jupyter_client.session import Session
@@ -21,8 +22,15 @@ from ..base.handlers import APIHandler, JupyterHandler
 from ..utils import url_path_join
 from .managers import GatewayClient
 
+warnings.warn(
+    "The jupyter_server.gateway.handlers module is deprecated and will not be supported in Jupyter Server 3.0",
+    DeprecationWarning,
+    stacklevel=2,
+)
+
+
 # Keepalive ping interval (default: 30 seconds)
-GATEWAY_WS_PING_INTERVAL_SECS = int(os.getenv("GATEWAY_WS_PING_INTERVAL_SECS", 30))
+GATEWAY_WS_PING_INTERVAL_SECS = int(os.getenv("GATEWAY_WS_PING_INTERVAL_SECS", "30"))
 
 
 class WebSocketChannelsHandler(WebSocketHandler, JupyterHandler):
@@ -229,7 +237,7 @@ class GatewayWebSocketClient(LoggingConfigurable):
 
         # NOTE(esevan): if websocket is not disconnected by client, try to reconnect.
         if not self.disconnected and self.retry < GatewayClient.instance().gateway_retry_max:
-            jitter = random.randint(10, 100) * 0.01
+            jitter = random.randint(10, 100) * 0.01  # noqa
             retry_interval = (
                 min(
                     GatewayClient.instance().gateway_retry_interval * (2**self.retry),
